@@ -43,6 +43,6 @@ def create_user_auth_pastaporto_action(user_id: int, jwt_auth_id: int) -> Pastap
         Action.AUTH,
         {
             "id": user_id,
-            'jwt_auth_id': jwt_auth_id
+            'jwtAuthId': jwt_auth_id
         }
     )
